summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/contactlist/kopetemetacontactlvi.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/contactlist/kopetemetacontactlvi.h')
-rw-r--r--kopete/kopete/contactlist/kopetemetacontactlvi.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kopete/kopete/contactlist/kopetemetacontactlvi.h b/kopete/kopete/contactlist/kopetemetacontactlvi.h
index 767330ba..d795475f 100644
--- a/kopete/kopete/contactlist/kopetemetacontactlvi.h
+++ b/kopete/kopete/contactlist/kopetemetacontactlvi.h
@@ -23,9 +23,9 @@
#include "kopetelistviewitem.h"
-#include <qobject.h>
-#include <qpixmap.h>
-#include <qptrdict.h>
+#include <tqobject.h>
+#include <tqpixmap.h>
+#include <tqptrdict.h>
#include <klistview.h>
@@ -56,8 +56,8 @@ class KopeteMetaContactLVI : public Kopete::UI::ListView::Item
public:
KopeteMetaContactLVI( Kopete::MetaContact *contact, KopeteGroupViewItem *parent );
- KopeteMetaContactLVI( Kopete::MetaContact *contact, QListViewItem *parent );
- KopeteMetaContactLVI( Kopete::MetaContact *contact, QListView *parent );
+ KopeteMetaContactLVI( Kopete::MetaContact *contact, TQListViewItem *parent );
+ KopeteMetaContactLVI( Kopete::MetaContact *contact, TQListView *parent );
~KopeteMetaContactLVI();
/**
@@ -74,7 +74,7 @@ public:
/**
* parent when top-level
*/
- QListView *parentView() const { return m_parentView; };
+ TQListView *parentView() const { return m_parentView; };
/**
* parent when not top-level
@@ -85,7 +85,7 @@ public:
* call this when the item has been moved to a different group
*/
void movedToDifferentGroup();
- void rename( const QString& name );
+ void rename( const TQString& name );
void startRename( int );
Kopete::Group *group();
@@ -97,28 +97,28 @@ public:
* (This is used for e.g. the context-menu of a contact when
* right-clicking an icon, or the tooltips)
*/
- Kopete::Contact *contactForPoint( const QPoint &p ) const;
+ Kopete::Contact *contactForPoint( const TQPoint &p ) const;
/**
* Returns the QRect small little icon used for the Kopete::Contact.
* The behavior is undefined if @param c doesn't point to a valid
* Kopete::Contact for this list view item.
* The returned QRect is using the list view item's coordinate
* system and should probably be transformed into the list view's
* coordinates before being of any practical use.
* Note that the returned Rect is always vertically stretched to fill
* the full list view item's height, only the width is relative to
* the actual icon width.
*/
- QRect contactRect( const Kopete::Contact *c ) const;
+ TQRect contactRect( const Kopete::Contact *c ) const;
bool isGrouped() const;
/**
* reimplemented from KListViewItem to take into account our alternate text storage
*/
- virtual QString text( int column ) const;
- virtual void setText( int column, const QString &text );
+ virtual TQString text( int column ) const;
+ virtual void setText( int column, const TQString &text );
public slots:
/**
@@ -134,7 +134,7 @@ public slots:
private slots:
void slotUpdateMetaContact();
void slotContactStatusChanged( Kopete::Contact * );
- void slotContactPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & );
+ void slotContactPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & );
void slotContactAdded( Kopete::Contact * );
void slotContactRemoved( Kopete::Contact * );
@@ -159,24 +159,24 @@ private:
void initLVI();
void setDisplayMode( int mode, int iconMode );
void setMetaContactToolTipSourceForComponent( Kopete::UI::ListView::Component *comp );
- QString key( int column, bool ascending ) const;
+ TQString key( int column, bool ascending ) const;
void updateContactIcon( Kopete::Contact * );
Kopete::UI::ListView::ContactComponent *contactComponent( const Kopete::Contact *c ) const;
Kopete::MetaContact *m_metaContact;
KopeteGroupViewItem *m_parentGroup;
- QListView *m_parentView;
+ TQListView *m_parentView;
bool m_isTopLevel;
int m_pixelWide;
Kopete::OnlineStatus m_oldStatus;
- QPixmap m_oldStatusIcon;
- QPixmap m_originalBlinkIcon;
+ TQPixmap m_oldStatusIcon;
+ TQPixmap m_originalBlinkIcon;
- QTimer *mBlinkTimer;
+ TQTimer *mBlinkTimer;
- QPtrDict<Kopete::Account> m_addContactActions;
+ TQPtrDict<Kopete::Account> m_addContactActions;
bool mIsBlinkIcon;
int m_blinkLeft;
@@ -97,28 +97,28 @@ public:
/**
- * Returns the QRect small little icon used for the Kopete::Contact.
+ * Returns the TQRect small little icon used for the Kopete::Contact.
* The behavior is undefined if @param c doesn't point to a valid
* Kopete::Contact for this list view item.
@@ -97,28 +97,28 @@ public:
* The behavior is undefined if @param c doesn't point to a valid
* Kopete::Contact for this list view item.
- * The returned QRect is using the list view item's coordinate
+ * The returned TQRect is using the list view item's coordinate
* system and should probably be transformed into the list view's
* coordinates before being of any practical use.